function stacklbl(axhandle,titl,ylab,x,y);
% function stacklbl(axhandle,titl,ylab,[x,y]);
%   labels the yaxis and titles a stack plot panel
%   created by timeplt.m 
%        axhandle= the handle of the axes you wish to label
%        titl = string for title
%        ylab = string for ylabel
%        x,y = location of title in normalized coordinates (0.05,.85) by default
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Use of this program is self described.
% Program written in Matlab v7.1.0 SP3
% Program ran on PC with Windows XP Professional OS.
%
% "Although this program has been used by the USGS, no warranty, 
% expressed or implied, is made by the USGS or the United States 
% Government as to the accuracy and functioning of the program 
% and related program material nor shall the fact of distribution 
% constitute any such warranty, and no responsibility is assumed 
% by the USGS in connection therewith."
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
if(~exist('x'))
 x=.05;
end
if(~exist('y'))
 y=.90;
end
axes(axhandle);...
ylabel(ylab);...
text(x,y,titl,'units','norm','color','k');
